OC.L10N.register(
    "calendar",
    {
    "Calendar" : "நாட்காட்டி",
    "Today" : "இன்று",
    "Week" : "வாரம்",
    "Month" : "மாதம்",
    "Download" : "பதிவிறக்குக",
    "Delete" : "நீக்குக",
    "Share link" : "Share link",
    "can edit" : "தொகுக்க முடியும்",
    "New calendar" : "புதிய நாட்காட்டி",
    "Cancel" : "இரத்து செய்க",
    "Actions" : "செயல்கள்",
    "Email" : "மின்னஞ்சல்",
    "Unknown" : "தெரியாத",
    "never" : "ஒருபோதும்",
    "Repeat" : "மீண்டும்",
    "Monday" : "திங்கட்கிழமை",
    "More" : "மேலதிக",
    "Save" : "சேமிக்க ",
    "Update" : "இற்றைப்படுத்தல்",
    "Personal" : "தனிப்பட்ட",
    "Details" : "விவரங்கள்",
    "Attendees" : "பங்கேற்பாளர்கள்",
    "Close" : "மூடுக",
    "Location" : "இடம்",
    "Description" : "விவரிப்பு"
},
"nplurals=2; plural=(n != 1);");
